@@ -21,7 +21,7 @@ typedef enum { TMPDIR_APP_OWNED = 0, TMPDIR_USER_OWNED = 1 } tmpdir_type_t;
 
 void set_tmpdir(const char *dir, tmpdir_type_t type, int max_files, int preserve_files);
 const char* get_tmpdir(void);
-void clean_tmpdir();
+void clean_tmpdir(void);
 
 const char* make_tmpdir(void);
 int check_dir_is_rw(const char* tmpdir);
